@@ -14,11 +14,11 @@ History : (15/02/2012) First named version.
         : (10/11/2015) resid, centerGauss and getBackground added.
         : (13/11/2015) MinMax added.
         : (18/11/2015) centerMoment added.
-        : (17/01/2023) AirmAss functions added.
+        : (17/01/2023) AirmAss functions added and then removed.
 """
 
 
-__all__ = ['AirMass', 'centerGauss', 'centerMoment', 'Counts2Mag',
+__all__ = ['centerGauss', 'centerMoment', 'Counts2Mag',
             'Mag2Counts', 'getBackground', 'MinMax', 'resid']
 
 
