@@ -2,10 +2,10 @@
 
 Context : SRP
 Module  : Sky
-Version : 1.0.1
+Version : 1.0.2
 Author  : Stefano Covino
-Date    : 02/09/2013
-E-mail  : stefano.covino@brera.inaf.it
+Date    : 19/01/2023
+E-mail  : stefano.covino@inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
 
@@ -15,10 +15,12 @@ Remarks :
 
 History : (18/02/2012) First named version.
         : (02/09/2013) New functions.
+        : (19/01/2023) AirMass added.
 """
 
 
-__all__ = ['AltitudeRate','AzimuthRate','HourAngle','ParallacticAngle','ParallacticAngleRate',
+__all__ = ['AirMass', 'AltitudeRate', 'AtmRefraction', 'AzimuthRate',
+            'HourAngle', 'ParallacticAngle','ParallacticAngleRate',
             'SiderealTime']
 
 
